==> piwigo-2.5.3.zip: piwigo/language/sl_SI/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['PHP 5 is required'] = 'Zahtevan PHP 5';
$lang['Password'] = 'Geslo';
$lang['Password ']['confirm'] = 'Geslo [potrdi]';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo bo poskušal preklopiti vaše nastavitve na PHP 5 z ustvarjanjem ali urejanjem .htacceess datoteke';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo ni mogel nastaviti PHP 5.';
$lang['Sorry!'] = 'Oprostite!';
$lang['Start Install'] = 'Začetek namestitve';
$lang['Try to configure PHP 5'] = 'Poskušam nastaviti PHP 5';
$lang['User'] = 'Uporabnik';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Uporabniki bodo ta elektronski naslov uporabljali za kontakt s skrbnikom spletne strani ';
$lang['Webmaster login'] = 'Prijava za spletne skrbnike';
$lang['Webmaster mail address'] = 'Elektronski naslov skrbnika';
$lang['Webmaster password'] = 'Skrbniško geslo';
$lang['Welcome to my photo gallery'] = 'Dobrodošli v mojo galerijo';
$lang['Welcome to your new installation of Piwigo!'] = 'Dobrodošli na vaši novi namestitvi Piwiga!';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Lahko prenesete namestitveno datoteko ter jo naložite v local/config imenik vaše namestitve.';
$lang['Admin configuration'] = 'Admin nastavitve';
$lang['Basic configuration'] = 'Osnovne nastavitve';
$lang['Can\'t connect to server'] = 'Ne morem se povezati s strežnikom';
$lang['Congratulations, Piwigo installation is completed'] = 'Čestitamo! Namestitev Piwigo aplikacije je uspešno dokončana!';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Uspešno ste se povezali na strežnik vendar je povezava s podatkovno bazo spodletela.';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Ustvarjanje nastavitvene datoteke local/config/database.inc.php je spodletelo.';
$lang['Database configuration'] = 'Nastavitve podatkovne baze';
$lang['Database name'] = 'Ime podatkovne baze';
$lang['Database table prefix'] = 'Predpona podatkovnih tabel';
$lang['Default gallery language'] = 'Privzeti jezik galerije';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Ne oklevajte in povprašajte za pomoč na našem forumu: %s';
$lang['Download the config file'] = 'Prenesite config datoteko';
$lang['Hope to see you back soon.'] = 'Upam, da se kmalu ponovno vidimo.';
$lang['Host'] = 'Gostitelj';
$lang['Installation'] = 'Namestitev';
$lang['It appears your webhost is currently running PHP %s.'] = 'Zdi se, da  je na spletnem strežniku trenutno nameščen PHP %s';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Pokazano bo obiskovalcem. To je potrebno za upravljanje spletne strani';
$lang['Just another Piwigo gallery'] = 'Samo še ena Piwigo galerija';
$lang['enter a login for webmaster'] = 'vnesite prijavno ime skrbnika';
$lang['localhost, sql.multimania.com, toto.freesurf.fr'] = 'localhost, sql.multimania.com, toto.freesurf.fr';
$lang['mail address must be like xxx@yyy.eee (example : jack@altern.org)'] = 'e-poštni naslov mora imeti obliko xxx@yyyy.zzz (primer:jack@altern.org)';
$lang['please enter your password again'] = 'prosimo ponovno vnesite vaše geslo';
$lang['user login given by your host provider'] = 'prijavno ime uporabnika pridobljeno od vašega ponudnika gostovanja';
$lang['user password given by your host provider'] = 'geslo uporabnika pridobljeno od vašega ponudnika gostovanja';
$lang['verification'] = 'preverjanje';
$lang['webmaster login can\'t contain characters \' or "'] = 'prijavno ime skrbnika ne sme vsebovati znakov \' ali "';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'imena tabel v podatkovni bazi bodo imela predpono. (omogoča lažje upravljanje tabel)';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Posvetujte se z vašim ponudnikom gostovanja kako bi lahko sami prešli na zahtevano PHP 5 različico.';
$lang['also given by your host provider'] = 'tudi pridobljeno od vašega ponudnika gostovanja';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Rabite pomoč? Zastavite vprašanje na <a href="%s">Piwigo message board</a>.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Upoštevajte da lahko sami spremenite nastavitve in nato ponovno zaženete Piwigo.';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Druga rešitev je, da kopirate besedilo v polje zgoraj in ga prilepite v datoteko "local/config/database.inc.php" (Opozorilo: database.inc.php mora vsebovati le to kar je v besedilnem polju, brez znakov prehoda v novo vrstico(line return)ali znakov za presledke)';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Varno shranite, omogoča vam dostop do administratorske nadzorne plošče!';
?>

==> piwigo-2.10.2.zip: piwigo/language/sl_SI/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+

$lang['PHP 5 is required'] = 'Zahtevan je PHP 5.2';
$lang['Password [confirm]'] = 'Geslo [potrdi]';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo bo poskušal preklopiti vaše nastavitve na PHP 5.2 z ustvarjanjem ali urejanjem .htacceess datoteke';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo ni mogel nastaviti PHP 5.2';
$lang['Sorry!'] = 'Oprostite!';
$lang['Start Install'] = 'Začni namestitev';
$lang['Try to configure PHP 5'] = 'Poskušam nastaviti PHP 5.2';
$lang['User'] = 'Uporabnik';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Obiskovalci bodo lahko ta elektronski naslov uporabljali za kontakt s skrbnikom spletne strani ';
$lang['Welcome to my photo gallery'] = 'Dobrodošli v moji foto galeriji';
$lang['Welcome to your new installation of Piwigo!'] = 'Dobrodošli v vaši novi namestitvi Piwigo!';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Lahko prenesete namestitveno datoteko ter jo naložite v local/config imenik vaše namestitve.';
$lang['Admin configuration'] = 'Admin nastavitve';
$lang['Basic configuration'] = 'Osnovne nastavitve';
$lang['Can\'t connect to server'] = 'Ne morem se povezati s strežnikom';
$lang['Congratulations, Piwigo installation is completed'] = 'Čestitamo! Namestitev Piwigo aplikacije je uspešno dokončana!';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Uspešno ste se povezali na strežnik vendar je povezava s podatkovno bazo spodletela.';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Ustvarjanje nastavitvene datoteke local/config/database.inc.php je spodletelo.';
$lang['Database configuration'] = 'Nastavitve podatkovne baze';
$lang['Database name'] = 'Ime podatkovne baze';
$lang['Database table prefix'] = 'Predpona podatkovnih tabel';
$lang['Default gallery language'] = 'Privzeti jezik galerije';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Ne oklevajte in povprašajte za pomoč na našem forumu: %s';
$lang['Download the config file'] = 'Prenesite config datoteko';
$lang['Hope to see you back soon.'] = 'Upam, da se kmalu ponovno vidimo.';
$lang['Host'] = 'Gostitelj';
$lang['Installation'] = 'Namestitev';
$lang['It appears your webhost is currently running PHP %s.'] = 'Zdi se, da  je na spletnem strežniku trenutno nameščen PHP %s';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Vidno bo obiskovalcem. To je potrebno za upravljanje spletne strani';
$lang['Just another Piwigo gallery'] = 'To je zgolj še ena Piwigo galerija';
$lang['enter a login for webmaster'] = 'vnesite prijavno ime skrbnika';
$lang['please enter your password again'] = 'prosimo ponovno vnesite vaše geslo';
$lang['user login given by your host provider'] = 'prijavno ime uporabnika pridobljeno od vašega ponudnika gostovanja';
$lang['user password given by your host provider'] = 'geslo uporabnika pridobljeno od vašega ponudnika gostovanja';
$lang['verification'] = 'preverjanje';
$lang['webmaster login can\'t contain characters \' or "'] = 'prijavno ime skrbnika ne sme vsebovati znakov \' ali "';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'imena tabel v podatkovni bazi bodo imela predpono. (omogoča lažje upravljanje tabel)';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Posvetujte se z vašim ponudnikom gostovanja kako bi lahko sami prešli na zahtevano PHP 5.2 različico.';
$lang['also given by your host provider'] = 'tudi pridobljeno od vašega ponudnika gostovanja';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Potrebujete dodatno pomoč? Zastavite vprašanje na <a href="%s">Piwigo oglasni deski</a>.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Upoštevajte da lahko sami spremenite nastavitve in nato ponovno zaženete Piwigo.';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Druga rešitev je, da kopirate besedilo v polje zgoraj in ga prilepite v datoteko "local/config/database.inc.php" (Opozorilo: database.inc.php mora vsebovati le to kar je v besedilnem polju, brez znakov prehoda v novo vrstico(line return)ali znakov za presledke)';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Varno shranite, omogoča vam dostop do administratorske nadzorne plošče!';
$lang['localhost or other, supplied by your host provider'] = 'localhost ali drug naslov ki ga imate pri svojem ponudniku gostovanja';
